/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.handler;

import org.apache.ws.resource.properties.v1_2.ResourceProperties1_2Constants;
import org.apache.ws.resource.lifetime.v1_2.ResourceLifetime1_2Constants;

import javax.xml.namespace.QName;
import java.util.HashMap;
import java.util.Map;

/**
 * Maps message-part element QNames from spec WSDLs to Java method names.
 *
 * @author Sal Campana, Ian P. Springer
 */
public class DefaultMethodMap
   extends AbstractSoapMethodNameMap
{

   private static final Map METHOD_MAP = initMap();

   private static Map initMap()
   {
      Map map = new HashMap(  );
      addWsrpOperations( map );
      addWsrlOperations( map );
      return map;
   }

   private static void addWsrpOperations( Map map )
   {
      map.put( new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "GetResourceProperty", ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA ),
                                         "getResourceProperty" );
      map.put( new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "QueryResourceProperties", ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA ),
                                         "queryResourceProperties" );
      map.put( new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "SetResourceProperties", ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA ),
                                         "setResourceProperties" );
      map.put( new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "GetMultipleResourceProperties", ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA ),
                                         "getMultipleResourceProperties" );
   }
   
   private static void addWsrlOperations( Map map )
   {
      map.put( new QName( ResourceLifetime1_2Constants.NSURI_WSRL_SCHEMA, "SetTerminationTime", ResourceLifetime1_2Constants.NSPREFIX_WSRL_SCHEMA ),
                                         "setTerminationTime" );
      map.put( new QName( ResourceLifetime1_2Constants.NSURI_WSRL_SCHEMA, "Destroy", ResourceLifetime1_2Constants.NSPREFIX_WSRL_SCHEMA ),
                                         "destroy" );
   }

   private SoapMethodNameMap m_parent;

   /**
    * Creates a new {@link DefaultMethodMap} object.
    *
    * @param parent DOCUMENT_ME
    */
   public DefaultMethodMap( SoapMethodNameMap parent )
   {
      m_parent = parent;
   }

   /**
    * DOCUMENT_ME
    *
    * @param request DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public String getDefaultMethodName( QName request )
   {
      return (String) METHOD_MAP.get( request );
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public SoapMethodNameMap getParent(  )
   {
      return m_parent;
   }
}