/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.lifetime.faults;

import org.apache.ws.resource.ResourceUnknownException;
import org.apache.ws.resource.i18n.MessagesImpl;
import org.apache.ws.resource.i18n.Keys;
import org.apache.ws.resource.faults.BaseFaultException;
import org.apache.ws.resource.lifetime.v1_2.ResourceLifetime1_2Constants;
import org.apache.ws.util.i18n.Messages;

import javax.xml.namespace.QName;

/**
 * LOG-DONE
 * Indicates that a WS-Resource could not be destroyed for some reason.
 *
 * @author Ian P. Springer
 */
public class ResourceNotDestroyedFaultException
   extends BaseFaultException
{
   public static final Messages MSG = MessagesImpl.getInstance();
   /**
    * DOCUMENT_ME
    */
   private static final QName NAME =
      new QName( ResourceLifetime1_2Constants.NSURI_WSRL_SCHEMA, "ResourceUnknownFault",
                 ResourceLifetime1_2Constants.NSPREFIX_WSRL_SCHEMA );
   private Object             m_resourceId;
   private String             m_serviceName;

   /**
    * Constructs a new ResourceUnknownFaultException, specifying the resource id and service name of the unknown
    * resource.
    *
    * @param resourceId
    * @param serviceName
    */
   public ResourceNotDestroyedFaultException( Object resourceId,
                                              String serviceName )
   {
      super( NAME );
      setDescription( new String[]
                      {
                         MSG.getMessage( Keys.UNABLE_TO_DESTROY_RESOURCE,serviceName,resourceId)
                      } );
      m_resourceId     = resourceId;
      m_serviceName    = serviceName;
   }

   /**
    * @param rue
    */
   public ResourceNotDestroyedFaultException( ResourceUnknownException rue )
   {
      // TODO
      this( rue.getResourceId(  ),
            rue.getServiceName(  ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public Object getResourceId(  )
   {
      return m_resourceId;
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public String getServiceName(  )
   {
      return m_serviceName;
   }
}