/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.properties.faults;

import org.apache.ws.resource.faults.BaseFaultException;
import org.apache.ws.resource.properties.v1_2.ResourceProperties1_2Constants;
import org.apache.ws.resource.i18n.MessagesImpl;
import org.apache.ws.resource.i18n.Keys;
import org.apache.ws.util.i18n.Messages;

import javax.xml.namespace.QName;

/**
 * LOG-DONE
 * WS-ResourceProperties UnableToModifyResourceProperty fault type implemented as a Java exception.
 *
 * @author Ian P. Springer
 */
public class UnableToModifyResourcePropertyFaultException
   extends BaseFaultException
{
    public static final Messages MSG = MessagesImpl.getInstance();
   /**
    * DOCUMENT_ME
    */
   private static final QName NAME =
      new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "UnableToModifyResourcePropertyFault",
                 ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA );
   private QName              m_propName;

   /**
    * Constructs a new UnableToModifyResourcePropertyFaultException.
    *
    * @param propName the name of the read-only property that the user attempted to modify
    */
   public UnableToModifyResourcePropertyFaultException( QName propName )
   {
      super( NAME );
      m_propName = propName;
      setDescription( new String[]
                      {
                         MSG.getMessage( Keys.READ_ONLY_PROP,propName)
                      } );
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public QName getPropertyName(  )
   {
      return m_propName;
   }
}